#    Cuttlefish buoyancy control in response to food availability and ocean acidification 

#   Eve Otjacques 1*, Tiago Repolho 1, Jos? Ricardo Paula 1, Silvia Sim?o 1, Miguel Baptista 1, Rui Rosa 1

# 1 MARE - Marine and Environmental Sciences Centre, Laboratorio Maritimo da Guia, Faculdade de Ciencias da Universidade de Lisboa, Av. Nossa Senhora do Cabo, 939, 2750-374 Cascais, Portugal
#
# 
# * Corresponding author: Eve Otjacques
#   E-mail: ebotjacques@fc.ul.pt


#Housekeeping
#Load packages from R and support functions 
library(MASS)
library(lattice)
library(mgcv)
library(lme4)
library(ggplot2)
library(plyr)
library(effects)
library(lmerTest)
library(car)
library(ggthemes)
library(ggplot2)
library(dplyr)
library(forcats)
library(hrbrthemes)
library(viridis)
library(r2glmm)
library(ggeffects)
library(sjmisc)
library(sjPlot)
require(survival)
require(psych)
require(survminer)
require(goftte)
library(coxme)
library(performance)
source("HighstatLibV10.R") # Functions from: Mixed effects models and extensions in ecology with R. (2009).
#Zuur, AF, Ieno, EN, Walker, N, Saveliev, AA, and Smith, GM. Springer. Copyright Highland Statistics LTD.


#Import the data from a tab delimited ascii file
data <- read.csv(file = "data_general.csv",
                 header = TRUE,
                 dec = ".")

### A. Data exploration ####
#1.) Outliers ####
names(data)
summary(data)
head(data)
MyVar <- c("tank","color","label","ID","treatment",
"hatching","hatching_date","days_until_hatching_trt","sampling_date","days_until_sampling",
"floating","feeding","weight","area","density")
Mydotplot(data[,MyVar]) #Ok

#2.) Collinearity ####
pairs(data[, MyVar], lower.panel = panel.cor) #Ok.


#3.) Are categorical covariates balanced? ####
names(data)
table(data$tank) #ok - 18 per tank
table(data$color) #ok - ok around 35 per color
table(data$treatment) #ok exactly 90 per treatment

#4.) tables ####
describeBy(data$days_until_sampling, data$floating, mat = TRUE)
data <- within(data, treatment <- relevel(treatment, ref = "C"))


##### B. Data analysis ####
##### 1.) Hatching success ####
### Kaplan-Meier estimates (survfit) and log-rank test (survdiff)

summary(data)

c2 <- Surv(data$days_until_hatching_trt, data$hatching) ## creating a surv object
C2.1 <- survdiff(c2~ color, data=data) # p<0.0001
C2 <- survfit(c2~ treatment, data=data)

describeBy(data$days_until_hatching_trt,list(data$treatment,data$hatching)
           ,mat = TRUE)

data <- within(data, treatment <- relevel(treatment, ref = "C"))

## Cox proportional hazards model with size class as random:

fit <- coxme(Surv(days_until_hatching_trt, hatching) ~ treatment  + (1|tank), data)
summary(fit)

Anova(fit)


# Since coxme doenst allow to perform schoenfeld test, change to coxph model
fit <- coxph(Surv(days_until_hatching_trt, hatching) ~ treatment, data)
fitcox.zph <- cox.zph(fit)
#plot schoenfeld test
ggcoxzph(fitcox.zph)

#Survival plot
plot1<-ggsurvplot(C2, data=data,
                  legend=c(0.2, 0.84),
                  conf.int = T, 
                  fun="event",
                  legend.title="",
                  ggtheme = theme_few(), 
                  palette = c("#E64B35FF", "#4DBBD5FF"),
                  alpha=1,
                  ylab="Proportion of hatched cuttlefish",
                  xlab="Number of days pre-hatching",
                  legend.lab = c("High CO2", "Control"))
plot1


##### 2.) Density after hatching #####

data_gy<- read.csv(file = "data_GY.csv",
                   header = TRUE,
                   dec = ".")
data_gy<-na.omit(data_gy)
summary(data_gy)
hist(data_gy$density)

describeBy(data_gy$density,list(data_gy$treatment)
           ,mat = TRUE)

M1<- lmer(density ~ treatment*days_until_hatching_trt + (1|tank) , data=data_gy)
drop1(M1)
Anova(M1)
summary(M1)
check_model(M1)

plot_model(M1, show.values=TRUE, type="pred", terms=c("days_until_hatching_trt","treatment"))


gp <- ggplot(data=data_gy, aes(x=days_until_hatching_trt, y=density, colour=treatment))

gp +  geom_point() + geom_smooth(method = "glm", method.args = list(family = "gaussian"))+labs(
  x = "Number of days pre-hatching", 
  y = bquote('Cuttlebone weight/area ratio ' * ~mg~mm^-2*""), 
  title = "",
  color ="Treatment"
) + scale_colour_brewer(palette = "Set1", labels = c(bquote('High'*~CO[2]*''), "Control")) +
  theme_few()+ theme(legend.title=element_blank()) + scale_fill_brewer()

##### 3.) Density newborns #####
## load a new data.frame with relevant variables 

data_f<- read.csv(file = "data_without_E_GY.csv",
                  header = TRUE,
                  dec = ".")

hist(data_f$density)

describeBy(data_f$density,list(data_f$treatment, data_f$feeding)
           ,mat = TRUE)

M2<- lmer(density ~ feeding*treatment*days_until_sampling + (1|tank), data=data_f)
plot_model(1, type="pred", terms=c("days_until_sampling", "feeding", "treatment" ))
drop1(M2)

summary(M2)
Anova(M2)

check_model(M2)

gp1 <- ggplot(data=data_f, aes(x=days_until_sampling, y=density, colour=treatment))

gp1 +  geom_point() + geom_smooth(method = "glm", method.args = list(family = "gaussian"))+labs(
  x = "Number of Days After Hatching", 
  y = bquote('Cuttlebone weight/area ratio '*~mg~mm^-2*""), 
  title = "",
  color ="Treatment"
) + xlim(8,30) + ylim(0.07,0.12) + facet_wrap("feeding", scales = "free") + scale_colour_brewer(palette = "Set1", labels = c(bquote('High'*~CO[2]*''), "Control")) +
  theme_few()+ theme(legend.title=element_blank()) + 
  scale_fill_brewer()


#### 4.) Floating rate  ####
### Kaplan-Meier estimates (survfit) and log-rank test (survdiff)
names(data)

summary(data_f)

describeBy(data_f$floating,list(data_f$feeding)
           ,mat = TRUE)

describeBy(data_f$floating,list(data_f$treatment)
           ,mat = TRUE)

c1 <- Surv(data_f$days_until_sampling, data_f$floating) ## creating a surv object
C1.1 <- survdiff(c1~ color, data=data_f) # p<0.0001
data_f$concate<-paste(data_f$feeding,data_f$treatment)
C1 <- survfit(c1~ concate, data=data_f)

## Cox proportional hazards model with size class as random:
data_f$floating <- as.numeric(data_f$floating)
names(data_f)

fit <- coxme(Surv(days_until_sampling, floating) ~ treatment*feeding + (1|days_until_hatching_trt) + (1|tank), data_f)
summary(fit)
Anova(fit)

# Since coxme doenst allow to perform schoenfeld test, change to coxph model
fit <- coxph(Surv(days_until_sampling, floating) ~ treatment*feeding, data_f)
fitcox.zph <- cox.zph(fit)
#plot schoenfeld test
ggcoxzph(fitcox.zph)

#Survival plot
plot2<-ggsurvplot(C1, data=data_f,
                 legend=c(0.2, 0.84),
                 conf.int = T, 
                 fun="event",
                 legend.title="",
                 ggtheme = theme_few(), 
                 palette = c("#E64B35FF",  "#4DBBD5FF"  ,"grey", "#00A087B2" ),
                 alpha=1,
                 ylab="Proportion of floaters",
                 xlab="Number of Days After Hatching",
                 legend.lab = c("Non-fed - High CO2", "Non-fed - Control", "Fed - High CO2", "Fed - Control"))
plot2




##### 5.) Density floaters vs non-floaters #####
data_feed<- read.csv(file = "data_feed_without_E_GY.csv",
                  header = TRUE,
                  dec = ".")
boxplot(data_feed$density~data_feed$floating*data_feed$treatment)
hist(data_f$density)
summary(data_feed)
data_feed$floating<-as.factor(data_feed$floating)
data_f$days_total<-data_f$days_until_sampling+data_f$days_until_hatching_trt

data_f$feeding <- as.factor(data_f$feeding)


describeBy(data_feed$density,list(data_feed$treatment)
           ,mat = TRUE)

describeBy(data_feed$density,list(data_feed$floating)
           ,mat = TRUE)

M3<- lmer(density ~ floating*treatment*days_until_sampling + (1|tank), data=data_feed)
plot_model(M3, type="pred", terms=c("days_until_sampling", "floating", "treatment" ))
summary(M3)

drop1(M3)

Anova(M3)

check_model(M3)

plot_model(M3, show.values=TRUE, type="pred", terms=c("days_until_sampling","treatment","feeding"))

data_feed$floating_1 <- factor(data_feed$floating, levels = c("0", "1"),
                  labels = c("Non-floater", "Floater")
)

gp2 <- ggplot(data=data_feed, aes(x=days_until_sampling, y=density, colour=floating_1))

gp2 +  geom_point() + geom_smooth(method = "glm", method.args = list(family = "gaussian"))+labs(
  x = "Number of Days After Hatching", 
  y = bquote('Cuttlebone weight/area ratio '*~mg~mm^-2*""), 
  title = "",
  color ="floating1"
) + xlim(8,30) + ylim(0.06,0.12) +  facet_wrap("treatment", scales = "free") + scale_colour_brewer(palette = "Set1") +
  theme_few()+ theme(legend.title=element_blank()) + 
  scale_fill_brewer()
